Module blaxel.knowledgebases.factory
====================================

Classes
-------

`KnowledgebaseConfig(type: str, knowledge_base: Dict[str, Any], connection: Dict[str, Any])`
:   

`KnowledgebaseFactory()`
:   

    ### Static methods

    `create(config: blaxel.knowledgebases.factory.KnowledgebaseConfig) ‑> blaxel.knowledgebases.types.KnowledgebaseClass`
    :